export async function loadScript({
  src,
  name,
  id,
  exportedName,
}: {
  src: string;
  id?: string;
  name: string;
  exportedName?: string;
}) {
  return await new Promise((resolve, reject) => {
    const script = document.createElement("script");
    script.type = "text/javascript";
    script.src = src;
    if (id) {
      script.id = id;
    }
    script.addEventListener("load", async () => {
      if (exportedName) {
        const exportedSymbol = exportedName
          .split(".")
          // eslint-disable-next-line @typescript-eslint/no-explicit-any
          .reduce((result: any, key: string) => result?.[key], window);
        resolve(exportedSymbol);
      } else {
        resolve(undefined);
      }
    });
    script.addEventListener("error", () => {
      reject(new Error(`Failed to load ${name} @ ${src}.`));
    });
    script.addEventListener("abort", () => {
      reject(new Error(`${name} @ ${src} load was aborted.`));
    });

    document.getElementsByTagName("head")[0].appendChild(script);
  });
}
